// This file is a part of "grblControl" application.
// Copyright 2015 Hayrullin Denis Ravilevich

#ifndef UTIL
#define UTIL

#include <QColor>
#include <QIcon>
#include <QImage>
#include <QAbstractButton>
#include <QVector3D>
#include <QEventLoop>
#include <QTimer>

class Util
{
public:
    static double nMin(double v1, double v2)
    {
        if (!std::isnan(v1) && !std::isnan(v2)) return qMin<double>(v1, v2);
        else if (!std::isnan(v1)) return v1;
        else if (!std::isnan(v2)) return v2;
        else return NAN;
    }

    static double nMax(double v1, double v2)
    {
        if (!std::isnan(v1) && !std::isnan(v2)) return qMax<double>(v1, v2);
        else if (!std::isnan(v1)) return v1;
        else if (!std::isnan(v2)) return v2;
        else return NAN;
    }

    static QVector3D colorToVector(QColor color)
    {
        return QVector3D(color.redF(), color.greenF(), color.blueF());
    }

    static void waitEvents(int ms)
    {
        QEventLoop loop;

        QTimer::singleShot(ms, &loop, SLOT(quit()));
        loop.exec();
    }

    static QIcon invertIconColors(QIcon icon)
    {
        QImage img = icon.pixmap(icon.actualSize(QSize(64, 64))).toImage();
        img.invertPixels();

        return QIcon(QPixmap::fromImage(img));
    }

    static void invertButtonIconColors(QAbstractButton *button)
    {
        button->setIcon(invertIconColors(button->icon()));
    }
};

#endif // UTIL

